<?php
/** 
 * checkdnsrr for Windows (from php.net) 
 * 
 * @param string $host a hostname 
 * @param string $type dns type check 
 * @return boolean 
 */ 
function win_checkdnsrr($host, $type='MX') { 
  if (strtoupper(substr(PHP_OS, 0, 3)) != 'WIN') { 
    return false; 
  } 
  if (empty($host)) { 
    return false; 
  } 
  $types = array('A', 'MX', 'NS', 'SOA', 'PTR', 'CNAME', 'AAAA', 'A6', 'SRV', 'NAPTR', 'TXT', 'ANY'); 
  if (!in_array($type, $types)) { 
    user_error("checkdnsrr() Type '$type' not supported", E_USER_WARNING); 
    return false; 
  } 
  @exec('nslookup -type=' . $type . ' ' . escapeshellcmd($host), $output); 
  foreach ($output as $line) { 
    if (preg_match('/^' . $host . '/', $line)) { 
      return true; 
    } 
  } 
  return false; 
} 

// Definisco la funzione 
if (!function_exists('checkdnsrr')) { 
  function checkdnsrr($host, $type='MX') { 
    return win_checkdnsrr($host, $type); 
  } 
} 

/** 
 * Email_Validator 1.0 
 * 
 * <code> 
 * $email  = 'email@domain.com'; 
 * if(Email_Validador::validate($email)) 
 *   echo "Valid email address."; 
 * else echo "Invalid email address."; 
 * </code> 
 * 
 * @author David Tavarez <contacto@davidtavarez.com> 
 * @version 1.0 
 */ 
final class Email_Validador { 

  /** 
   * Lista dei domini in black list. 
   * 
   * @var array 
   * @access private 
   * 
  static private $_blacklist_domains = array("bl.spamcop.net", "list.dsbl.org", "sbl.spamhaus.org"); 

  /** 
   * Verify if a domain is on black list. 
   * 
   * @param string $domain domain name. 
   * @access public 
   * @return boolean 
   */ 
  public static function check_domain_is_blacklisted($domain) { 
    if (preg_match("/^[a-z0-9][a-z0-9\-]+[a-z0-9](\.[a-z]{2,4})+$/i", $domain)) { 
      $ip = gethostbyname($domain); 
      $reverse_ip = implode(".", array_reverse(explode(".", $ip))); 
      foreach (self::$_blacklist_domains as $dnsbl_list) { 
        if (checkdnsrr($reverse_ip . "." . $dnsbl_list . ".", "A")) 
          return $reverse_ip . "." . $dnsbl_list; 
      } 
    } 
    return false; 
  } 

  /** 
   * Verifico che l'email sia nel formato corretto 
   * 
   * @param string $email an email adress. 
   * @access public 
   * @return boolean 
   */ 
  public static function check_string($email) { 
    return preg_match('/^([a-z0-9])(([-a-z0-9._])*([a-z0-9]))*\@([a-z0-9])'.'(([a-z0-9-])*([a-z0-9]))+'.'(\.([a-z0-9])([-a-z0-9_-])?([a-z0-9])+)+$/i', $email); 
  } 

  /** 
   * Completo la validazione dell'indirizzo email 
   * 
   * @param string $email a email adress. 
   * @access public 
   * @return boolean 
   */ 
  public static function validate($email) { 
    if (self::check_string($email)) { 
      $ar = explode("@", $email); 
      $domain = $ar[1]; 
      unset($ar); 
      if (self::check_domain_is_blacklisted($domain)) { 
        if (self::validate_domain($domain))
          return true; 
      } 
    } 
    return false; 
  } 

  /** 
   * Verifico che sia valido il dominio 
   * 
   * @param string $domain a domain name. 
   * @access public 
   * @return boolean 
   */ 
  public static function validate_domain($domain) { 
    if (preg_match("/^[a-z0-9][a-z0-9\-]+[a-z0-9](\.[a-z]{2,4})+$/i", $domain)) { 
      if ($this->_domain_is_blacklisted($domain) === false) { 
        if (checkdnsrr($domain, 'MX'))
          return true; 
        if (checkdnsrr($domain, 'A'))
          return true; 
      } 
    } 
  } 
} 

//Funzione di controllo dell'inserimento dati corretti. 
function ver_testo($testo,$min,$max){ 
  //  $pattern="/^(?!^[0-9]*$)(?!^[a-zA-Z]*$)^([a-zA-Z0-9]{6,15}){".$min.",".$max."}$/"; //Controllo lunghezza username tra 6 e 15 caratteri compresi i jolly 
  $pattern="/^[a-zA-Z0-9]{".$min.",".$max."}$/";//non prende direttamente il min e il max 
  if(preg_match($pattern, $testo)){ 
    //testo ok 
    return TRUE; 
  } else { 
    return FALSE; 
  } 
} //Chiudo funzione verifica lunghezza dati inseriti 

function controllodata($eta){ 
  //"/^[0-9]{1,2}\/[0-9]{1,2}\/[0-9]{4}$/" 
  if (!preg_match("/^[0-9]{1,2}\/[0-9]{1,2}\/[0-9]{4}$/", $eta)) { 
    return false; 
  } else { 
    $arrayData = explode("/",$eta ); 
    $Giorno = $arrayData[0]; 
    $Mese = $arrayData[1]; 
    $Anno = $arrayData[2]; 
    if(!checkdate($Mese,$Giorno,$Anno)){ 
      return FALSE; 
    } else { 
      return TRUE; 
    } 
  } 
} 
?>
